@@ -124,7 +124,7 @@ class ChangeProcess(Module):
 
             self._change_time = self._simulation_time
             logging.debug(
-                "********* A CHANGE OCCURRED [{}/{}] ********".format(
+                "A change occurred [{}/{}]".format(
                     self._change_time, self._max_duration
                 )
             )
@@ -566,7 +566,7 @@ class Ellipsoids(Policy):
 
             param_size = (num_post_change_states, num_states)
 
-            self._free_params = np.ones(size=param_size)
+            self._free_params = 0.5 * np.ones(size=param_size)
 
             logging.info(
                 "Ellipsoid constructor set params : {}".format(self._free_params)
@@ -597,7 +597,9 @@ class Ellipsoids(Policy):
         return CONTINUE
 
     def __repr__(self):
-        return "Ellipsoids"
+        return "Ellipsoids".format(
+            self._free_params, self.ellipsoids
+        )
 
     def __iter__(self):
         yield ("type", self.__repr__())
@@ -633,7 +635,7 @@ class Ellipsoids(Policy):
         Returns:
             numpy.ndarray: Optimisation parameters
         """
-        return expit(ellipsoid_coefficients / np.sqrt(2))
+        return logit(ellipsoid_coefficients)
 
     @staticmethod
     def _deparameterise(free_parameters):
@@ -646,7 +648,7 @@ class Ellipsoids(Policy):
         Returns:
             [type]: [description]
         """
-        return np.sqrt(2) * logit(free_parameters)
+        return expit(free_parameters)
 
 
 class Dynamics(Module):
@@ -916,7 +918,9 @@ class _StoppingProblem(ModuleFactory, FilterMixin):
 
         for step in range(steps):
 
-            logging.debug("Started optimisation step {}".format(step))
+            logging.debug(
+                " ******* Started optimisation step {}/{} ********".format(step, steps)
+            )
 
             old_params = self._policy.free_params
 
@@ -930,6 +934,9 @@ class _StoppingProblem(ModuleFactory, FilterMixin):
             params1 = old_params + perturbation_vector
             params2 = old_params - perturbation_vector
 
+            logging.debug("Param set 1 under test:\n {}".format(params1))
+            logging.debug("Param set 2 under test:\n {}".format(params2))
+
             self._policy.free_params = params1
             loss_accumulator = np.float64(0)
 
